@@ -12,13 +12,13 @@ from google.oauth2.credentials import Credentials
 from google_auth_oauthlib.flow import InstalledAppFlow
 from googleapiclient.discovery import build
 
-from .utils import BotGmailMessage, GmailDefaultLabels
+from .utils import BotGmailMessage, GmailDefaultLabels, SearchBy
 
 
 class BotGmailPlugin:
     def __init__(self, credentials_file_path: str, user_email: str) -> None:
         """
-        BotGmailPlugin
+        BotGmailPlugin.
 
         Args:
             credentials_file_path (str): The path of the credentials json file obtained at Google Cloud Platform.
@@ -56,9 +56,11 @@ class BotGmailPlugin:
                         customized_labels: List[str] = None, mark_read=False, timeout=0) -> List[BotGmailMessage]:
         """
         Search for messages based on criteria and labels.
+
         [See how to use and more details about searches](https://support.google.com/mail/answer/7190)
 
         To see the labels that are available in the email, use get_mail_labels()
+
         [See more details about messages labels](https://developers.google.com/gmail/api/guides/labels)
 
         Args:
@@ -122,7 +124,6 @@ class BotGmailPlugin:
         new_message = self.__build_message(text_content, to_addrs, cc_addrs, bcc_addrs, attachments, use_html)
         new_message["Subject"] = subject
         message = {'raw': base64.urlsafe_b64encode(new_message.as_bytes()).decode()}
-
         self.gmail_service.users().messages().send(userId="me", body=message).execute()
 
     def reply(self, msg: BotGmailMessage, text_content: str, attachments: List[str] = None,
@@ -154,7 +155,7 @@ class BotGmailPlugin:
     def reply_to_all(self, msg: BotGmailMessage, text_content: str, attachments: List[str] = None,
                      use_html: bool = False) -> None:
         """
-        Replies to all email addresses included in the original message.
+        Reply to all email addresses included in the original message.
 
         Args:
             msg (BotGmailMessage): The message to reply.
@@ -181,7 +182,8 @@ class BotGmailPlugin:
             include_attachments (boolean, optional): Include attachments from the original message.
             use_html (bool): The boolean value when you want to use body in html format.
         """
-        forwarded_message = self.__build_message(msg.text, to_addrs, cc_addrs, bcc_addrs, is_forwarded=True, use_html=use_html)
+        forwarded_message = self.__build_message(msg.text, to_addrs, cc_addrs, bcc_addrs, is_forwarded=True,
+                                                 use_html=use_html)
         forwarded_message["Subject"] = "Fwd: " + msg.subject
         if include_attachments:
             for part in msg.attachments:
@@ -244,6 +246,28 @@ class BotGmailPlugin:
         """
         self.gmail_service.users().messages().trash(userId='me', id=msg.id_).execute()
 
+    def delete_label(self, label_id: str) -> None:
+        """
+        Move a label to trash.
+
+        Args:
+            label_id (str): Label id to delete.
+        """
+        self.gmail_service.users().labels().delete(userId='me', id=label_id).execute()
+
+    def get_label(self, by: SearchBy, value: str) -> dict:
+        """
+        Search label by name.
+
+        Args:
+            by (SearchBy): Enum to search by
+            value (str): Value to search
+        """
+        label = [label for label in self.get_mail_labels() if label.get(by) == value]
+        if not label:
+            raise Exception("It was not possible to identify the Id of the Label.")
+        return label[0]
+
     def get_mail_labels(self) -> List[dict]:
         """
         Get all valid labels from email.
