@@ -13,31 +13,27 @@ class BotGmailMessage(MailMessage):
 
     @property
     def id_(self):
-        """
-        The id of the gmail message
-        """
+        """The id of the gmail message."""
         return str(self._msg_response.get('id'))
 
     @property
     def thread_id(self):
-        """
-        The thread id of the gmail message
-        """
+        """The thread id of the gmail message."""
         return str(self._msg_response.get('threadId'))
 
     @property
     def labels(self):
-        """
-        The message labels
-        """
+        """The message labels."""
         return self._msg_labels
 
 
 class GmailDefaultLabels(str, Enum):
     """
-    The class with the enumerated Gmail dafault labels
+    The class with the enumerated Gmail dafault labels.
+
     Usage: GmailDefaultLabels.<LABEL_NAME>
     """
+
     INBOX = "INBOX"
     SPAM = "SPAM"
     TRASH = "TRASH"
@@ -51,3 +47,14 @@ class GmailDefaultLabels(str, Enum):
     CATEGORY_PROMOTIONS = "CATEGORY_PROMOTIONS"
     CATEGORY_UPDATES = "CATEGORY_UPDATES"
     CATEGORY_FORUMS = "CATEGORY_FORUMS"
+
+
+class SearchBy(str, Enum):
+    """
+    The class with the enumerated search by labels.
+
+    Usage: SearchBy.<LABEL_NAME>
+    """
+
+    ID = "id"
+    NAME = "name"
